/**
 * A hook to receive data from the client in the following schema:
 *
 * {
 *     "app": "app-name",
 *     "method": "method-name",
 *     "data": { anyValue: 1 }
 * }
 *
 * @param app {string} The app name which the client will emit to
 * @param event {string} The specific `method` field that should be listened for.
 * @param handler {function} The callback function that will handle data received from the client
 * @returns {void} void
 * @example
 * const [dataState, setDataState] = useState<boolean>();
 * useNuiEvent<boolean>("appname", "methodname", setDataState);
 **/
export declare const useNuiEvent: <D = unknown>(app: string, event: string, handler: (r: D) => void) => void;
